#ifndef NT2_INCLUDE_FUNCTIONS_REAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REAL_HPP_INCLUDED

#include <nt2/complex/include/functions/real.hpp>

#endif
